==> xl-react-components-0.16.62.tgz: package/app/xl-react-dip/xl-react-dip-ci/xl-react-dip-ci-component.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import classNames from 'classnames';
import {xlMessageTypeProp} from '../../xl-props/xl-message-type-prop';
import {XlReactWidgetAutocomplete} from '../../xl-react-widget/xl-react-widget-autocomplete/xl-react-widget-autocomplete'; // eslint-disable-line max-len
import {XlReactFormItemControl} from '../../xl-react-form/xl-react-form-item-control';

import './xl-react-dip-ci.less';

export class XlReactDipCiComponent extends PureComponent {
    static propTypes = {
        className: PropTypes.string,
        controlClassName: PropTypes.string,
        disabled: PropTypes.bool,
        handlers: PropTypes.object,
        message: xlMessageTypeProp,
        messageHandler: PropTypes.func,
        metadata: PropTypes.object,
        model: PropTypes.string,
        objLabel: PropTypes.string,
        onMessageChange: PropTypes.func,
        onModelChange: PropTypes.func,
        onPristinityChange: PropTypes.func,
        onValidityChange: PropTypes.func,
        register: PropTypes.func,
        required: PropTypes.bool,
        showSearchIcon: PropTypes.bool,
        toggleButton: PropTypes.node
    };

    static defaultProps = {displayMode: 'edit', metadata: {}, objLabel: 'id'};

    render() {
        const {
            className, controlClassName, disabled, messageHandler, handlers, message, model, objLabel, onMessageChange,
            onModelChange, onPristinityChange, onValidityChange, register, required, showSearchIcon, toggleButton
        } = this.props;
        const metadata = R.omit(['default', 'description', 'label'], this.props.metadata);

        return <XlReactFormItemControl {...({
            ...this.props.metadata,
            controlClass: classNames('xl-react-dip-ci', controlClassName),
            message
        })}>
            <XlReactWidgetAutocomplete {...({
                addons: toggleButton,
                className,
                disabled,
                handlers,
                message,
                messageHandler,
                metadata,
                model,
                objLabel,
                onMessageChange,
                onModelChange,
                onPristinityChange,
                onValidityChange,
                register,
                required,
                showSearchIcon
            })}
            />
        </XlReactFormItemControl>;
    }
}

==> xl-react-components-0.21.12.tgz: package/app/xl-react-dip/xl-react-dip-ci/xl-react-dip-ci-component.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import classNames from 'classnames';
import {xlMessageTypeProp} from '../../xl-props/xl-message-type-prop';
import {XlReactWidgetAutocomplete} from '../../xl-react-widget/xl-react-widget-autocomplete/xl-react-widget-autocomplete'; // eslint-disable-line max-len
import {XlReactFormItemControl} from '../../xl-react-form/xl-react-form-item-control';

import './xl-react-dip-ci.less';

export class XlReactDipCiComponent extends PureComponent {
    static propTypes = {
        className: PropTypes.string,
        controlClassName: PropTypes.string,
        disabled: PropTypes.bool,
        handlers: PropTypes.object,
        message: xlMessageTypeProp,
        messageHandler: PropTypes.func,
        metadata: PropTypes.object,
        model: PropTypes.string,
        objLabel: PropTypes.string,
        onMessageChange: PropTypes.func,
        onModelChange: PropTypes.func,
        onPristinityChange: PropTypes.func,
        onValidityChange: PropTypes.func,
        pristine: PropTypes.bool,
        register: PropTypes.func,
        required: PropTypes.bool,
        showSearchIcon: PropTypes.bool,
        toggleButton: PropTypes.node,
        valid: PropTypes.bool
    };

    static defaultProps = {displayMode: 'edit', metadata: {}, objLabel: 'id'};

    render() {
        const {
            className,
            controlClassName,
            disabled,
            messageHandler,
            handlers,
            message,
            model,
            objLabel,
            onMessageChange,
            onModelChange,
            onPristinityChange,
            onValidityChange,
            pristine,
            register,
            required,
            showSearchIcon,
            toggleButton,
            valid
        } = this.props;
        const metadata = R.omit(['default', 'description', 'label'], this.props.metadata);

        return <XlReactFormItemControl {...({
            ...this.props.metadata,
            controlClass: classNames('xl-react-dip-ci', controlClassName),
            message
        })}>
            <XlReactWidgetAutocomplete {...({
                addons: toggleButton,
                className,
                disabled,
                handlers,
                independent: true,
                message,
                messageHandler,
                metadata,
                model,
                objLabel,
                onMessageChange,
                onModelChange,
                onPristinityChange,
                onValidityChange,
                pristine,
                register,
                required,
                showSearchIcon,
                valid
            })}
            />
        </XlReactFormItemControl>;
    }
}
